@@ -9,7 +9,7 @@ use JSON::PP qw( encode_json );
 use Encode qw( encode_utf8 );
 
 # ABSTRACT: Dist::Zilla initialization tasks for Plicease
-our $VERSION = '1.84'; # VERSION
+our $VERSION = '1.85'; # VERSION
 
 
 with 'Dist::Zilla::Role::AfterMint';
@@ -236,7 +236,7 @@ sub gather_file_gitattributes
   
   my $file = Dist::Zilla::File::InMemory->new({
     name    => '.gitattributes',
-    content => "*.t linguist-language=Perl\n*.h linguist-language=C\n",
+    content => "*.pm linguist-language=Perl\n*.h linguist-language=C\n",
   });
   
   $self->add_file($file);
@@ -328,7 +328,7 @@ Dist::Zilla::Plugin::Author::Plicease::Init2 - Dist::Zilla initialization tasks
 
 =head1 VERSION
 
-version 1.84
+version 1.85
 
 =head1 DESCRIPTION
 
