@@ -10,7 +10,7 @@ use Term::ANSIColor ();
 use Path::Class qw( file dir );
 
 # ABSTRACT: Dist::Zilla plugin bundle used by Plicease
-our $VERSION = '1.84'; # VERSION
+our $VERSION = '1.85'; # VERSION
 
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -159,23 +159,26 @@ sub configure
 
   ));
   
-  $self->add_plugins([
-    'ReadmeAnyFromPod' => {
-            type            => 'text',
-            filename        => 'README',
-            location        => 'build', 
-      maybe source_filename => $self->payload->{readme_from},
-    },
-  ]);
+  unless($self->payload->{no_readme})
+  {
+    $self->add_plugins([
+      'ReadmeAnyFromPod' => {
+              type            => 'text',
+              filename        => 'README',
+              location        => 'build', 
+        maybe source_filename => $self->payload->{readme_from},
+      },
+    ]);
   
-  $self->add_plugins([
-    'ReadmeAnyFromPod' => ReadMePodInRoot => {
-      type                  => 'markdown',
-      filename              => 'README.md',
-      location              => 'root',
-      maybe source_filename => $self->payload->{readme_from},
-    },
-  ]);
+    $self->add_plugins([
+      'ReadmeAnyFromPod' => ReadMePodInRoot => {
+        type                  => 'markdown',
+        filename              => 'README.md',
+        location              => 'root',
+        maybe source_filename => $self->payload->{readme_from},
+     },
+   ]);
+  }
   
   $self->add_plugins([
     'Author::Plicease::MarkDownCleanup' => {
@@ -257,7 +260,7 @@ Dist::Zilla::PluginBundle::Author::Plicease - Dist::Zilla plugin bundle used by
 
 =head1 VERSION
 
-version 1.84
+version 1.85
 
 =head1 SYNOPSIS
 
